Analyser

Struct Analyser 

pub struct Analyser<T: Literal, S: LiteralStorage<T>, const N: usize = 12> {
    pub count: usize,
    /* private fields */
}
Encapsulates the state and methods for performing conflict analysis.

Using a struct allows for reusing allocations (like seen and to_bump) across multiple conflict analyses, which can improve performance.

Type Parameters

  • T: The type of Literal.
  • S: The LiteralStorage type for clauses.
  • N: A compile-time constant for the inline capacity of to_bump SmallVec. Defaults to 12, a common small size for literals involved in resolution steps.

Fields

count: usize

A counter for the number of conflicts analysed for statistics.