pub enum PropagatorType {
WatchedLiterals,
UnitSearch,
UnitPropagationWithPureLiterals,
}Expand description
Enum representing the type of propagator to use in the SAT solver.
Variants
WatchedLiterals
Watched literals propagator, which uses the watched literals scheme for efficient unit propagation.
UnitSearch
Unit search propagator, which iterates through clauses to find unit clauses.
UnitPropagationWithPureLiterals
Unit propagation with pure literals, which combines unit propagation with the heuristic of assigning pure literals.
Implementations
Sourceimpl PropagatorType
impl PropagatorType
Sourcepub fn to_impl<L: Literal, S: LiteralStorage<L>, A: Assignment>(
self,
cnf: &Cnf<L, S>,
) -> PropagatorImpls<L, S, A>
pub fn to_impl<L: Literal, S: LiteralStorage<L>, A: Assignment>( self, cnf: &Cnf<L, S>, ) -> PropagatorImpls<L, S, A>
Converts the PropagatorType to a specific propagator implementation.